[PATCH] staging: r8188eu: Add queue_index to xdp_rxq_info

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Queue_index from the xdp_rxq_info is populated in cpumap file.
Using the NR_CPUS, results in patch check warning, as recommended,
using the num_possible_cpus() instead of NR_CPUS

Signed-off-by: Varshini Elangovan <varshini.elangovan@xxxxxxxxx>
---
 kernel/bpf/cpumap.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/kernel/bpf/cpumap.c b/kernel/bpf/cpumap.c
index 650e5d21f90d..756fd81f474c 100644
--- a/kernel/bpf/cpumap.c
+++ b/kernel/bpf/cpumap.c
@@ -102,8 +102,8 @@ static struct bpf_map *cpu_map_alloc(union bpf_attr *attr)
 
 	bpf_map_init_from_attr(&cmap->map, attr);
 
-	/* Pre-limit array size based on NR_CPUS, not final CPU check */
-	if (cmap->map.max_entries > NR_CPUS) {
+	/* Pre-limit array size based on num_possible_cpus, not final CPU check */
+	if (cmap->map.max_entries > num_possible_cpus()) {
 		err = -E2BIG;
 		goto free_cmap;
 	}
@@ -227,7 +227,7 @@ static int cpu_map_bpf_prog_run_xdp(struct bpf_cpu_map_entry *rcpu,
 
 		rxq.dev = xdpf->dev_rx;
 		rxq.mem = xdpf->mem;
-		/* TODO: report queue_index to xdp_rxq_info */
+		rxq.queue_index = ++i;
 
 		xdp_convert_frame_to_buff(xdpf, &xdp);
 
-- 
2.25.1




[Index of Archives]     [Linux Samsung SoC]     [Linux Rockchip SoC]     [Linux Actions SoC]     [Linux for Synopsys ARC Processors]     [Linux NFS]     [Linux NILFS]     [Linux USB Devel]     [Video for Linux]     [Linux Audio Users]     [Yosemite News]     [Linux Kernel]     [Linux SCSI]


  Powered by Linux